@@ -43,12 +43,13 @@ class LetsEncrypt:
         return tldextract.extract(
             self.hostname).subdomain
 
-    def _query_acme_challenge_records(self, hostname: str, hosted_zone: str) -> bool:
+    def _query_acme_challenge_records(self, hostname: str, hosted_zone_id: str) -> bool:
         client = boto3.client('route53')
         paginator = client.get_paginator(
             'list_resource_record_sets')
+        print('hosted_zone_id', hosted_zone_id, hostname)
         try:
-            for page in paginator.paginate(HostedZoneId=hosted_zone):
+            for page in paginator.paginate(HostedZoneId=hosted_zone_id):
                 for record in page["ResourceRecordSets"]:
                     if (f'_acme-challenge.{hostname}') in record['Name']:
                         return True
@@ -71,8 +72,13 @@ class LetsEncrypt:
     def _validate_subdelegate_zone(self, subject_alternative_names: List[str]) -> None:
         client = boto3.client('route53')
         for hostname in subject_alternative_names:
-            hosted_zone = os.environ['HOSTED_ZONE_ID']
-            if not self._query_acme_challenge_records(hostname, hosted_zone):
+            # TODO: Update Other Function to Use registered_domain
+            subdomain = tldextract.extract(hostname).registered_domain
+            hosted_zone_id = client.list_hosted_zones_by_name(
+                DNSName=f'{subdomain}.',
+                MaxItems='1'
+            )['HostedZones'][0]['Id'].split('/')[-1]
+            if not self._query_acme_challenge_records(hostname, hosted_zone_id):
                 LOGGER.warning('Invalid Challenge Alias: {hostname}'.format(
                     hostname=hostname))
                 sys.exit(1)
@@ -133,3 +139,28 @@ class LetsEncrypt:
             '{directory}/.acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
             directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
+
+    # TODO: Validate ACME Private CA
+    # def acme_private_ca_local(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
+    #     prefix = os.environ['PREFIX']
+    #     root_certificate = get_secret(
+    #         f'{prefix}/otter/root_certificate', element=None, region=self.region)
+    #     with open('root_ca.crt', 'w') as outfile:
+    #         outfile.write(root_certificate)
+
+    #     subprocess.call(
+    #         '{directory}/.acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
+    #     subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+    #         directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
+
+    # def acme_private_ca_production(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
+    #     prefix = os.environ['PREFIX']
+    #     root_certificate = get_secret(
+    #         f'{prefix}/otter/root_certificate', element=None, region=self.region)
+    #     with open('root_ca.crt', 'w') as outfile:
+    #         outfile.write(root_certificate)
+
+    #     subprocess.call(
+    #         '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
+    #     subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+    #         directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
