@@ -74,9 +74,10 @@ def update_certificate_expiration(hostname: str, certificate_expiration: str) ->
             Key={
                 'system_name': hostname
             },
-            UpdateExpression="SET certificate_expiration = :certificate_expiration",
+            UpdateExpression="SET certificate_expiration = :certificate_expiration, certificate_validation = :certificate_validation",
             ExpressionAttributeValues={
-                ":certificate_expiration": certificate_expiration
+                ":certificate_expiration": certificate_expiration,
+                ":certificate_validation": "True"
             },
             ReturnValues="UPDATED_NEW"
         )
